OC.L10N.register(
    "contactsinteraction",
    {
    "Recently contacted" : "最近聯絡",
    "Contacts Interaction" : "聯絡人互動",
    "Manages interaction between accounts and contacts" : "管理賬戶與聯絡人間的互動",
    "Collect data about accounts and contacts interactions and provide an address book for the data" : "蒐集關於賬戶與聯絡人互動的資料，並提供資料的通訊錄",
    "Manages interaction between users and contacts" : "管理用戶與聯絡人間的互動",
    "Collect data about user and contacts interactions and provide an address book for the data" : "蒐集關於用戶與聯絡人互動的資料，並提供資料的通訊錄"
},
"nplurals=1; plural=0;");
